Module flatten

Module flatten 

Functions

flatten
Flatten an ABI file by resolving all imports and inlining types. Returns the flattened AbiFile.
flatten_to_yaml
Flatten an ABI file and return the result as a YAML string.
flatten_with_options
Flatten an ABI file with verbose output option.
normalize_type_refs
Normalize FQDN type references to simple names using the import resolver.