Functions
- flatten
- Flatten an ABI file by resolving all imports and inlining types. Returns the flattened AbiFile.
- flatten_
to_ yaml - Flatten an ABI file and return the result as a YAML string.
- flatten_
with_ options - Flatten an ABI file with verbose output option.
- normalize_
type_ refs - Normalize FQDN type references to simple names using the import resolver.